@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-12-01'; # DATE
+our $DATE = '2022-07-23'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.042'; # VERSION
+our $VERSION = '0.043'; # VERSION
 
 sub meta {
     +{
@@ -43,10 +43,11 @@ sub coerce {
         "",
         "do { ",
         "my \$tmp = $dt; \$tmp = [\$tmp] unless ref \$tmp eq 'ARRAY'; ",
-        "my \$i = 0; ",
-        "while (\$i < \@\$tmp) { ",
+        "my \$i = -1; ",
+        "while (++\$i < \@\$tmp) { ",
+        "  next if \$tmp->[\$i] =~ /=/; ", # probably a perl::modname_with_optional_args instead of just perl::modname, skip expanding wildcard
         "  \$tmp->[\$i] =~ s!/!::!g; ",
-        "  my \$el = \$tmp->[\$i++]; ",
+        "  my \$el = \$tmp->[\$i]; ",
         "  next unless String::Wildcard::Bash::contains_wildcard(\$el); ",
         "  my \$mods = PERLANCAR::Module::List::list_modules(" . (defined($ns_prefix) ? Data::Dmp::dmp($ns_prefix) . " . " : "") . "\$el, {wildcard=>1, list_modules=>1}); ",
         "  my \@mods = sort keys \%\$mods; ",
@@ -75,7 +76,7 @@ Data::Sah::Coerce::perl::To_array::From_str_or_array::expand_perl_modname_wildca
 
 =head1 VERSION
 
-This document describes version 0.042 of Data::Sah::Coerce::perl::To_array::From_str_or_array::expand_perl_modname_wildcard (from Perl distribution Sah-Schemas-Perl), released on 2021-12-01.
+This document describes version 0.043 of Data::Sah::Coerce::perl::To_array::From_str_or_array::expand_perl_modname_wildcard (from Perl distribution Sah-Schemas-Perl), released on 2022-07-23.
 
 =head1 DESCRIPTION
 
@@ -146,7 +147,7 @@ beyond that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2022, 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
