@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-12-01'; # DATE
+our $DATE = '2022-07-23'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.042'; # VERSION
+our $VERSION = '0.043'; # VERSION
 
 sub meta {
     +{
@@ -21,8 +21,6 @@ prerequisite.
 
 _
         args => {
-            str => {schema=>'str*', req=>1},
-            n => {schema=>'uint*', default=>1},
         },
     };
 }
@@ -58,7 +56,7 @@ Data::Sah::Value::perl::Perl::this_dist
 
 =head1 VERSION
 
-This document describes version 0.042 of Data::Sah::Value::perl::Perl::this_dist (from Perl distribution Sah-Schemas-Perl), released on 2021-12-01.
+This document describes version 0.043 of Data::Sah::Value::perl::Perl::this_dist (from Perl distribution Sah-Schemas-Perl), released on 2022-07-23.
 
 =head1 DESCRIPTION
 
@@ -95,7 +93,7 @@ beyond that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2022, 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
