@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-12-01'; # DATE
+our $DATE = '2022-07-23'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.042'; # VERSION
+our $VERSION = '0.043'; # VERSION
 
 use Regexp::Pattern::Perl::Module ();
 
@@ -125,70 +125,11 @@ Sah::Schema::perl::modname_with_optional_args - Perl module name (e.g. Foo::Bar)
 
 =head1 VERSION
 
-This document describes version 0.042 of Sah::Schema::perl::modname_with_optional_args (from Perl distribution Sah-Schemas-Perl), released on 2021-12-01.
+This document describes version 0.043 of Sah::Schema::perl::modname_with_optional_args (from Perl distribution Sah-Schemas-Perl), released on 2022-07-23.
 
 =head1 SYNOPSIS
 
-To check data against this schema (requires L<Data::Sah>):
-
- use Data::Sah qw(gen_validator);
- my $validator = gen_validator("perl::modname_with_optional_args*");
- say $validator->($data) ? "valid" : "INVALID!";
-
- # Data::Sah can also create validator that returns nice error message string
- # and/or coerced value. Data::Sah can even create validator that targets other
- # language, like JavaScript. All from the same schema. See its documentation
- # for more details.
-
-To validate function parameters against this schema (requires L<Params::Sah>):
-
- use Params::Sah qw(gen_validator);
-
- sub myfunc {
-     my @args = @_;
-     state $validator = gen_validator("perl::modname_with_optional_args*");
-     $validator->(\@args);
-     ...
- }
-
-To specify schema in L<Rinci> function metadata and use the metadata with
-L<Perinci::CmdLine> to create a CLI:
-
- # in lib/MyApp.pm
- package MyApp;
- our %SPEC;
- $SPEC{myfunc} = {
-     v => 1.1,
-     summary => 'Routine to do blah ...',
-     args => {
-         arg1 => {
-             summary => 'The blah blah argument',
-             schema => ['perl::modname_with_optional_args*'],
-         },
-         ...
-     },
- };
- sub myfunc {
-     my %args = @_;
-     ...
- }
- 1;
-
- # in myapp.pl
- package main;
- use Perinci::CmdLine::Any;
- Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
-
- # in command-line
- % ./myapp.pl --help
- myapp - Routine to do blah ...
- ...
-
- % ./myapp.pl --version
-
- % ./myapp.pl --arg1 ...
-
-Sample data:
+=head2 Sample data and validation results against this schema
 
  ""  # INVALID
 
@@ -212,6 +153,105 @@ Sample data:
 
  ["Foo",["arg1","arg2"],{}]  # INVALID (Too many elements)
 
+=head2 Using with Data::Sah
+
+To check data against this schema (requires L<Data::Sah>):
+
+ use Data::Sah qw(gen_validator);
+ my $validator = gen_validator("perl::modname_with_optional_args*");
+ say $validator->($data) ? "valid" : "INVALID!";
+
+The above schema returns a boolean result (true if data is valid, false if
+otherwise). To return an error message string instead (empty string if data is
+valid, a non-empty error message otherwise):
+
+ my $validator = gen_validator("perl::modname_with_optional_args", {return_type=>'str_errmsg'});
+ my $errmsg = $validator->($data);
+ 
+ # a sample valid data
+ $data = ["Foo",{arg1=>1,arg2=>2}];
+ my $errmsg = $validator->($data); # => ""
+ 
+ # a sample invalid data
+ $data = ["Foo",["arg1","arg2"],{}];
+ my $errmsg = $validator->($data); # => "Length must be at most 2"
+
+Often a schema has coercion rule or default value, so after validation the
+validated value is different. To return the validated (set-as-default, coerced,
+prefiltered) value:
+
+ my $validator = gen_validator("perl::modname_with_optional_args", {return_type=>'str_errmsg+val'});
+ my $res = $validator->($data); # [$errmsg, $validated_val]
+ 
+ # a sample valid data
+ $data = ["Foo",{arg1=>1,arg2=>2}];
+ my $res = $validator->($data); # => ["",["Foo",{arg1=>1,arg2=>2}]]
+ 
+ # a sample invalid data
+ $data = ["Foo",["arg1","arg2"],{}];
+ my $res = $validator->($data); # => ["Length must be at most 2",["Foo",["arg1","arg2"],{}]]
+
+Data::Sah can also create validator that returns a hash of detailed error
+message. Data::Sah can even create validator that targets other language, like
+JavaScript, from the same schema. Other things Data::Sah can do: show source
+code for validator, generate a validator code with debug comments and/or log
+statements, generate human text from schema. See its documentation for more
+details.
+
+=head2 Using with Params::Sah
+
+To validate function parameters against this schema (requires L<Params::Sah>):
+
+ use Params::Sah qw(gen_validator);
+
+ sub myfunc {
+     my @args = @_;
+     state $validator = gen_validator("perl::modname_with_optional_args*");
+     $validator->(\@args);
+     ...
+ }
+
+=head2 Using with Perinci::CmdLine::Lite
+
+To specify schema in L<Rinci> function metadata and use the metadata with
+L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
+
+ # in lib/MyApp.pm
+ package
+   MyApp;
+ our %SPEC;
+ $SPEC{myfunc} = {
+     v => 1.1,
+     summary => 'Routine to do blah ...',
+     args => {
+         arg1 => {
+             summary => 'The blah blah argument',
+             schema => ['perl::modname_with_optional_args*'],
+         },
+         ...
+     },
+ };
+ sub myfunc {
+     my %args = @_;
+     ...
+ }
+ 1;
+
+ # in myapp.pl
+ package
+   main;
+ use Perinci::CmdLine::Any;
+ Perinci::CmdLine::Any->new(url=>'/MyApp/myfunc')->run;
+
+ # in command-line
+ % ./myapp.pl --help
+ myapp - Routine to do blah ...
+ ...
+
+ % ./myapp.pl --version
+
+ % ./myapp.pl --arg1 ...
+
 =head1 DESCRIPTION
 
 Perl module name with optional arguments which will be used as import arguments,
@@ -257,7 +297,7 @@ beyond that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2022, 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
